_sagemath: Downstream package of Sage in distributions
======================================================

SageMath is available from various distributions and can be installed
by package managers.

This dummy package records the names of the system packages that
should be installed to provide a standard installation of SageMath,
including documentation and Jupyter.


Downstream Contact
------------------

See `wiki page Distribution <https://github.com/sagemath/sage/wiki/Distribution>`_
